@@ -45,7 +45,7 @@ def test_no_additional_name_in_table_name():
     assert _cast_table_name("TableName") == "TableName"
 
 
-# @mock_dynamodb2
+@mock_dynamodb2
 class TestDynamoDBBase(TestCase):
     table_name = "TableForTests"
     actual_cwd = str()
@@ -66,11 +66,11 @@ class TestDynamoDBBase(TestCase):
         self.raw_schema = load_single(
             Path(Path(__file__).parent, f"test_data/tables/{self.table_name}.json")
         )
-        # create_dynamo_db_table_from_schema(self.raw_schema)
+        create_dynamo_db_table_from_schema(self.raw_schema)
 
     def tearDown(self) -> None:
         from dynamo_db_resource.table_existence import delete_dynamo_db_table
-        # delete_dynamo_db_table(self.table_name, require_confirmation=False)
+        delete_dynamo_db_table(self.table_name, require_confirmation=False)
         chdir(self.actual_cwd)
 
 
